@@ -13,7 +13,7 @@
 #' @export
 tidypredict_sql <- function(model, con) {
   f <- tidypredict_fit(model)
-  if (class(f) == "call") {
+  if (inherits(f, "call")) {
     dbplyr::translate_sql(!!f, con = con)
   } else {
     map(f, ~ dbplyr::translate_sql(!!.x, con = con))
@@ -37,7 +37,7 @@ tidypredict_sql <- function(model, con) {
 #' @export
 tidypredict_sql_interval <- function(model, con, interval = 0.95) {
   f <- tidypredict_interval(model, interval)
-  if (class(f) == "call") {
+  if (inherits(f, "call")) {
     dbplyr::translate_sql(!!f, con = con)
   } else {
     map(f, ~ dbplyr::translate_sql(!!.x, con = con))
